#!/bin/bash
# epgscan.sh by Frank Jepsen
#
# Scans for EPG Data on first channels via svdrpsend.pl
#
# Add a call like this to the start of the runvdr script:
# /usr/share/vdr/epgscan.sh &
#
# or add this to /etc/inittab
# ep:12345:once:/usr/share/vdr/epgscan.sh
#
# You can test by adding any single parameter e.g. "test"
# By doing this only a scan is performed

CONFFILE="/etc/vdr/vdr-addon-hw-wakeup.conf"
VDRCONFFILE="/var/lib/vdr/setup.conf"
SVDRPSEND="/usr/share/vdr/svdrpsend.pl"
CHANNELCONF="/var/lib/vdr/channels.conf"
LOGFILE="/var/log/epgscan.log"

LOG()
{
  logger -t epgscan $1
}

LOGF()
{
  logger -t epgscan -f $1
}

# read arguments from conf-file
if [ -e $CONFFILE ]; then
  LOG "Using ConfFile $CONFFILE."
. $CONFFILE
else
  LOG "ConfFile $CONFFILE not found. Using defaults."
fi

# Get old Channel
OldChannel=`cat $VDRCONFFILE | grep "^CurrentChannel" | awk -F= '{print$2}'`

[ -z "$EPG_MAX_CHANNEL" ]	&& export EPG_MAX_CHANNEL="50"
[ -z "$EPG_TIME_PER_CHANNEL" ]	&& export EPG_TIME_PER_CHANNEL="20"
[ -z "$EPG_STARTMIN" ]		&& export EPG_STARTMIN="5"
[ -z "$EPG_WAIT_BEFORE_START" ]	&& export EPG_WAIT_BEFORE_START="30"
[ -z "$EPG_UPDATE_AUTOTIMER" ]  && export EPG_UPDATE_AUTOTIMER="1"
[ -z "$EPG_VDRADMINPASS" ]      && export EPG_VDRADMINPASS="linvdr"

# Testmode
if [ "$1" ] && [ "$1" -eq "test" ]
then
  LOG "Testmode"
  DAILY_TIMER_STD="0"
  DAILY_TIMER_MIN="0"
  TESTMODE="1"
fi

if [ -z $DAILY_TIMER_STD ] || [ -z $DAILY_TIMER_MIN ]
then
  LOG "No Daily Timer specified."
else
  # only start within EPG_STARTMIN minutes after DAILYTIMER
  NOW=$((`date +%s`))
  TODAY=`date +"%m/%d/%Y"`
  DAILYTIMER=`date -d "$TODAY $DAILY_TIMER_STD:$DAILY_TIMER_MIN" +"%d.%m.%Y %H:%M"`
  LOG "DailyTimer: $DAILYTIMER"
  DAILYTIMER=`date -d "$TODAY $DAILY_TIMER_STD:$DAILY_TIMER_MIN" +%s`
  LOG "DailyTimer: $DAILYTIMER"
  if [ $TESTMODE ] || [ $NOW -gt $DAILYTIMER ]
  then
    DAILYTIMER=`expr $DAILYTIMER + $EPG_STARTMIN \* 60`
    if [ $TESTMODE ] || [ $DAILYTIMER -gt $NOW ]
    then
      LOG "DailyTimer in $EPG_STARTMIN Range"
      LOG "Starting EPGScan in $EPG_WAIT_BEFORE_START seconds"
      # Let VDR start completely before starting to scan
      sleep $EPG_WAIT_BEFORE_START

      Channel="0"
      for Freq in `cat $CHANNELCONF | egrep -v -e "^:" | awk -F: '{print$2}' `
      do
        Channel=`expr $Channel + 1`
        LOG "Channel:$Channel Freq:$Freq"
        if [ -z ${ScannedFreq[$Freq]} ]; then
          $SVDRPSEND CHAN $Channel > $LOGFILE
  	  LOGF $LOGFILE
	  
          ScannedFreq[$Freq]="1"
          sleep $EPG_TIME_PER_CHANNEL
        fi
        if [ $Channel -eq $EPG_MAX_CHANNEL ]; then
          break
        fi
      done

      # switch to previous channel
      $SVDRPSEND CHAN $OldChannel > $LOGFILE
      LOGF $LOGFILE
      sleep 5

      # shutdown VDR
      if [ -z $TESTMODE ]
      then
        $SVDRPSEND HITK Power > $LOGFILE
    	LOGF $LOGFILE
      fi
      rm $LOGFILE

      if [ $EPG_UPDATE_AUTOTIMER -eq "1" ]
      then      
        LOG "Updating Autotimer"
        wget "http://linvdr:$EPG_VDRADMINPASS@127.0.0.1/vdradmin.pl?aktion=force_update" -T 30 -O /dev/null
      fi
    else
     LOG "Not started in DailyTimer StartWindow"
    fi
  else
    LOG "Not started in DailyTimer StartWindow"
  fi
fi
